export default {
  type: "object",
  additionalProperties: false,
  properties: {
    change_types: {
      items: {
        additionalProperties: false,
        properties: {
          keywords: {
            items: {
              type: "string",
            },
            type: "array",
          },
          level: {
            enum: ["major", "minor", "patch"],
          },
          title: {
            type: "string",
          },
        },
        type: "object",
      },
      type: "array",
    },
    project: {
      additionalProperties: false,
      properties: {
        homepage: {
          description: "url of the project's homepage",
          examples: ["https://github.com/yanick/app-changelord"],
          type: ["string", "null"],
        },
        name: {
          description: "name of the project",
          examples: ["App::Changelord"],
          type: ["null", "string"],
        },
        ticket_url: {
          description:
            "perl code that takes a ticket string (e.g. 'GH123') via the `$_` variable and turns it into a link.",
          examples: [
            "s!GH(\\d+)!https://github.com/yanick/App-Changelord/issue/$1/",
            {
              '/^\\d+$/ ? "https://.../$_"': "undef",
            },
          ],
          type: "string",
        },
        with_stats: {
          description: "if true, add git statistics when bumping the version.",
        },
        next_directory: {
          type: "string",
          description:
            "directory where the changes for the NEXT release are stashed",
        },
      },
      type: "object",
    },
    releases: {
      items: {
        oneOf: [
          {
            type: "string",
          },
          {
            additionalProperties: false,
            properties: {
              changes: {
                items: {
                  $ref: "#/$defs/change",
                },
                type: "array",
              },
              date: {
                type: ["null", "string"],
              },
              version: {
                type: ["null", "string"],
              },
            },
            type: "object",
          },
        ],
      },
      type: "array",
    },
  },
  $defs: {
    change: {
      oneOf: [
        {
          type: "string",
        },
        {
          additionalProperties: false,
          properties: {
            commit: {
              type: ["string", "null"],
            },
            desc: {
              type: "string",
            },
            ticket: {
              type: ["string", "null"],
            },
            type: {
              type: ["string", "null"],
            },
          },
          required: ["desc"],
          type: "object",
        },
      ],
    },
  },
};
