import simpleGit from "simple-git";
import { prop, compact, pickBy } from "remeda";

const handler = async (config) => {
  const next = await config.next_release();
  const seen_sha1s = compact(next?.changes.map(prop("commit")));
  const seen_descs = next?.changes.map((change) =>
    typeof change === "string" ? change : change.desc
  );

  const git = config.git();

  const { version } = await config.latest_version();

  let { all: commits } = await git.log({
    from: "v" + version,
  });

  config.consola.start(`gathering changes since v${version}`);

  commits = commits.filter(({ hash }) => !seen_sha1s.includes(hash));

  const regex = new RegExp(
    (await config.changelog().project?.commit_regex) ??
      /^(?<type>[^: ]+):\s*(?<desc>.*?)(\[(?<ticket>[^\]]+)\])?$/
  );

  const changes = commits
    .map((commit) => [commit, commit.message.match(regex)])
    .filter((x) => x[1])
    .filter((x) => !seen_descs.includes(x[1].groups.desc))
    .map(([commit, res]) =>
      pickBy({ ...res.groups, commit: commit.hash }, (x) => x)
    );

  if (changes.length === 0) {
    config.consola.success("no changes detected");
    return;
  }

  for (const change of changes) {
    config.consola.info(`${change.type}: ${change.desc}`);
    config.add_to_next(change);
  }
  config.consola.success("done");
};

export default {
  command: "git-gather",
  desc: "gather change entries from git commits",
  builder: (yargs) => {
    yargs;
  },
  handler,
};
