import yaml from "yaml";
import fs from "fs-extra";

export async function latest_version() {
    const changelog = await this.changelog();

    return changelog.releases.find(({ version }) => version !== "NEXT");
}

const handler = async (config) => {
    const latest_version = config.latest_version()?.version ?? "0.0.0";

    if (config.json) {
        config.consola.raw(latest_version);
    } else {
        config.consola.raw(latest_version.version);
    }
};

export default {
    command: "latest-version",
    desc: "output the latest version present in the changelog",
    builder: (yargs) => {
        yargs
            .boolean("json")
            .describe("json", "output latest version entry as json");
    },
    handler,
};
